/* Install/UnInstall script for World Clock */

PARSE ARG action
IF RxFuncQuery('SysLoadFuncs') THEN DO
    CALL RxFuncAdd 'SysLoadFuncs', 'RexxUtil', 'SysLoadFuncs'
    CALL SysLoadFuncs
END
CALL RxFuncAdd  'FastIniStart','FastIni','FastIniStart'
CALL RxFuncAdd  'FastIniEnd','FastIni','FastIniEnd'

CALL SysCls
action = TRANSLATE(LEFT(action,1))
SELECT
    WHEN action = 'I' THEN CALL InstallMe
    WHEN action = 'U' THEN CALL UnInstallMe
    OTHERWISE CALL WhatAction
END
Exit

/* End of Install.cmd */

/* WhatAction - no action selected */

WhatAction:     PROCEDURE

CALL SysCls
SAY ' '
SAY 'Please enter installation parameter (I=Install, U=UnInstall, other=Exit):'
ans = TRANSLATE(SysGetKey('ECHO'))
SELECT
    WHEN ans = 'I' THEN CALL InstallMe
    WHEN ans = 'U' THEN CALL UnInstallMe
    OTHERWISE CALL NoAction 'Installation failed.'
END
RETURN

/* End of WhatAction */

/* NoAction - abort Install */

NoAction:   PROCEDURE

PARSE ARG noinstmsg
SAY ' '
SAY noinstmsg
SAY 'Press any key to exit ...'
ans = SysGetKey('NOECHO')
Exit

/* End of NoAction */

/* InstallMe - install World Clock */

InstallMe:  PROCEDURE

progname = 'World Clock'
required = 'WClock.exe CITIES.DAT WClock.dll ENGLISH.INI'
IF RIGHT(Directory(),2) = ':\' THEN DO
    SAY 'Problem! '||progname||' can not be installed in root directory.'
    SAY 'Create directory for '||progname||', copy files there and start this procedure again.'
    SAY 'Press any key to exit ...'
    ans = SysGetKey('NOECHO')
    Exit
END

CALL SysCls
SAY 'Welcome to '||progname||' Installation procedure!'
SAY 'Your files are in directory: '||Directory()
SAY 'This procedure will create Program object for '||progname||','
SAY 'Press "Y" to start Installation, any other key to exit...'
ans = TRANSLATE(SysGetKey('ECHO'))
SELECT
    WHEN ans = 'Y' THEN NOP
    OTHERWISE CALL NoAction 'Installation aborted.'
END

SAY ' '
SAY 'Checking files:'
DO i = 1 TO WORDS(required)
    chkfile = STREAM(WORD(required,i),'C','QUERY EXISTS')
    SELECT
        WHEN chkfile = '' THEN CALL NoAction LEFT(WORD(required,i),15)||' - Missing file. Installation failed!'
        OTHERWISE SAY '- '||LEFT(WORD(required,i),15)||' - OK'
    END
END

SAY ' '
inifile = 'WCLOCK.INI'
set.1 = 'Clock 1 5 2 200 50 1 1 0 0'
set.2 = 'Bubble 300 3 9.WarpSans#255 255 132'
set.3 = 'Font 9.WarpSans'
set.4 = 'Color #0'
set.5 = 'Banner 1 1 20 10'
set.6 = 'Free 0 0 0 0'
set.7 = 'Date 1 1 1 1 0 1 1'
set.8 = 'Time 1 1 0 1 1 0'
set.9 = 'Universal 0 1 0 0 0'
set.10 = 'Calendar 1 480 1020 1_default'
set.11 = 'TimeSound 1 1 1 1 1 1'
set.12 = 'WorldTime 1 World0.met'
set.13 = 'Messages 1 1 1 1 1 1 1'
set.14 = 'Confirm 1 1'
set.0 = 14

SAY ' '
SAY 'Searching previous version of '||progname
oldini = SysIni('USER','ToolsByGoran','WorldClockINIfile')
SAY ' '
SELECT
    WHEN oldini = 'ERROR:' THEN SAY 'Install procedure can not find previous version.'
    WHEN STREAM(oldini,'C','QUERY EXISTS') = '' THEN SAY 'Install procedure can not find previous version.'
    OTHERWISE DO
        SAY 'Previous version of '||progname||' found in directory:'
        SAY FILESPEC('drive',oldini)||FILESPEC('path',oldini)
        SAY 'Press "Y" if you want to copy settings from previous version.'
        ans = TRANSLATE(SysGetKey('ECHO'))
        SAY ' '
        IF ans = 'Y' THEN DO
            SAY ' '
            SAY 'Copying settings:'
            DO s = 1 TO set.0
                PARSE VALUE set.s WITH setkey setval
                oldset = SysIni(oldini,'Settings',setkey)
                IF WORDS(oldset) = WORDS(setval) THEN DO
                    CALL SysIni inifile, 'Settings', setkey, setval
                END
            END
            SAY 'Copying selected cities:'
            DO c = 1 TO 9
                cty = SysIni(oldini,'SelCity',c)
                SELECT
                    WHEN cty = 'UTC, Coordinated Universal Time' THEN CALL SysIni inifile, 'Cities', c, 'UTC, <regions>'
                    WHEN cty <> 'ERROR:' THEN CALL SysIni inifile, 'Cities', c, cty
                    OTHERWISE NOP
                END
            END
        END
    END
END

SAY ' '
SAY 'Writing default values to '||inifile
iniRc = FastIniStart('WCLOCK.INI','IniHandle')

SAY '- Language'
CALL SysIni inifile,'Language','ENGLISH','English.inf'
CALL SysIni inifile,'Settings','CurrLang','ENGLISH'
SAY '- Settings'
DO s = 1 TO set.0
    PARSE VALUE set.s WITH setkey setval
    oldset = SysIni(inifile,'Settings',setkey)
    SELECT
        WHEN oldset = 'ERROR:' THEN CALL SysIni inifile, 'Settings', setkey, setval
        WHEN WORDS(oldset) <> WORDS(setval) THEN CALL SysIni inifile, 'Settings', setkey, setval
        OTHERWISE NOP
    END
END

SAY '- Cities'
DO i = 1 TO 30
    IF SysIni(inifile,'Cities',i) = 'ERROR:' THEN DO
        CALL SysIni inifile,'Cities',i,'UTC, <regions>'
    END
END

SAY '- Custom'
IF SysIni(inifile,'CityHint','10') = 'ERROR:' THEN DO
    CALL SysIni inifile,'CityHint','10','1 This is my city'
END
IF SysIni(inifile,'CityHint','11') = 'ERROR:' THEN DO
    CALL SysIni inifile,'CityHint','11','4'
END
IF SysIni(inifile,'CityHint','12') = 'ERROR:' THEN DO
    CALL SysIni inifile,'CityHint','12','5'
END
IF SysIni(inifile,'CityHint','13') = 'ERROR:' THEN DO
    CALL SysIni inifile,'CityHint','13','3'
END
IF SysIni(inifile,'Events','3') = 'ERROR:' THEN DO
    CALL SysIni inifile,'Events','3','Time is changed from Standard time to Daylight Saving time. Please adjust your clock!'||'01'x||'<WP_CLOCK>'
END
IF SysIni(inifile,'Events','3') = 'ERROR:' THEN DO
    CALL SysIni inifile,'Events','4','Time is changed from Daylight Saving time to Standard time. Please adjust your clock!'||'01'x||'<WP_CLOCK>'
END

SAY '- World maps'
CALL SysIni inifile,'WorldMap','World0.met','Default World map'
CALL SysIni inifile,'WorldMap','World1.met','Political World map'
CALL SysIni inifile,'WorldMap','World2.met','Relief World map'
CALL SysIni inifile,'WorldMap','World3.met','World map made from satellite photos (without clouds)'
CALL SysIni inifile,'WorldMap','World4.met','Night World map with city lights'

iniRc = FastIniEnd('IniHandle')

SAY ' '
InstallDir = Directory()

FoldTitle='World Clock'||'^Version 1.3.0'
Icon1=Directory()||'\Folder1.ico'
Icon2=Directory()||'\Folder2.ico'
Icon='ICONFILE='Icon1||';ICONNFILE=1,'||Icon2
Setup='OBJECTID=<WCLOCK130_FOLDER>;'||Icon||''
Action = 'U'
dummy = SysCreateObject('WPFolder',FoldTitle,'<WP_DESKTOP>',Setup,Action)
SAY FoldTitle||' Folder - '||rc1(dummy)

ProgTitle = progname
EXE = 'WClock.exe'
ICO = 'WClock.ico'
Setup = 'OBJECTID=<WCLOCK130_PROG>;EXENAME='InstallDir'\'EXE';ICONFILE='InstallDir'\'ICO';STARTUPDIR='InstallDir''
Action = 'U'
dummy = SysCreateObject('WPProgram',ProgTitle,'<WCLOCK130_FOLDER>',Setup,Action)
SAY progname||' Program object - '||rc1(dummy)

ProgTitle = progname||'^(Personal REXX)'
EXE = 'WClockPR.cmd'
ICO = 'WClock.ico'
Setup = 'OBJECTID=<WCLOCK130_PREX>;EXENAME='InstallDir'\'EXE';ICONFILE='InstallDir'\'ICO';STARTUPDIR='InstallDir''
Action = 'U'
dummy = SysCreateObject('WPProgram',ProgTitle,'<WCLOCK130_FOLDER>',Setup,Action)
SAY ProgTitle||' - '||rc1(dummy)

ProgTitle = 'Read me 1st'||'^(English)'
EXE = 'E.exe'
INF = 'ReadEng.1st'
Setup = 'OBJECTID=<WCLOCK130_1STENG>;EXENAME='EXE';PARAMETERS='InstallDir'\'INF';STARTUPDIR='InstallDir''
Action = 'U'
dummy = SysCreateObject('WPProgram',ProgTitle,'<WCLOCK130_FOLDER>',Setup,Action)
SAY progname||' ReadMe.1st (English) - '||rc1(dummy)

ProgTitle = progname||'^History (English)'
EXE = 'E.exe'
INF = 'HistEng.txt'
Setup = 'OBJECTID=<WCLOCK130_HSTENG>;EXENAME='EXE';PARAMETERS='InstallDir'\'INF';STARTUPDIR='InstallDir''
Action = 'U'
dummy = SysCreateObject('WPProgram',ProgTitle,'<WCLOCK130_FOLDER>',Setup,Action)
SAY progname||' History (English) - '||rc1(dummy)

ProgTitle = progname||'^manual (English)'
EXE = 'View.exe'
INF = 'English.inf'
Setup = 'OBJECTID=<WCLOCK130_HLPENG>;EXENAME='EXE';PARAMETERS='InstallDir'\'INF';STARTUPDIR='InstallDir''
Action = 'U'
dummy = SysCreateObject('WPProgram',ProgTitle,'<WCLOCK130_FOLDER>',Setup,Action)
SAY progname||' manual (English) - '||rc1(dummy)

SAY ' '
SAY 'Installation finished. Press any key to exit ...'
ans = SysGetKey('NOECHO')
Exit

/* End of InstallMe */

/* UnInstallMe - uninstall World Clock */

UnInstallMe: PROCEDURE

progname = 'World Clock'
CALL SysCls
SAY 'This is '||progname||' UnInstallation procedure!'
SAY 'Your files are in directory: '||Directory()
SAY 'This procedure will destroy '||progname||' Program object'
SAY 'Press "Y" to start UnInstall, any other key to exit...'
ans = TRANSLATE(SysGetKey('ECHO'))
SELECT
    WHEN ans = 'Y' THEN NOP
    OTHERWISE CALL NoAction 'UnInstall aborted.'
END
SAY ' '
SAY 'Destroying Program objects and Folder'
CALL SysDestroyObject '<WCLOCK130_HSTSWE>'
CALL SysDestroyObject '<WCLOCK130_1STSWE>'
CALL SysDestroyObject '<WCLOCK130_HSTFRE>'
CALL SysDestroyObject '<WCLOCK130_1STFRE>'
CALL SysDestroyObject '<WCLOCK130_HLPFRE>'
CALL SysDestroyObject '<WCLOCK130_HSTDUT>'
CALL SysDestroyObject '<WCLOCK130_1STDUT>'
CALL SysDestroyObject '<WCLOCK130_HSTENG>'
CALL SysDestroyObject '<WCLOCK130_1STENG>'
CALL SysDestroyObject '<WCLOCK130_HLPENG>'
CALL SysDestroyObject '<WCLOCK130_PREX>'
CALL SysDestroyObject '<WCLOCK130_PROG>'
CALL SysDestroyObject '<WCLOCK130_FOLDER>'
SAY ' '
SAY 'UnInstallation complete.'
SAY 'You can delete files in directory '||Directory()
SAY 'To install '||progname||' again, start Install I. Press any key to exit...'
ans = SysGetKey('NOECHO')
Exit

/* End of UnInstallMe */

/* rc1 - return code - SysCreateObject */

rc1:        PROCEDURE

PARSE ARG rcSysCreateObject
SELECT
    WHEN rcSysCreateObject = 0 THEN rc1 = 'Error'
    OTHERWISE rc1 = 'OK'
END
RETURN rc1

/* End of rc1 */
